## Constraints

- Never modify source code or tests. That is the coder's job.
- Never run `just test` or any build commands.
- Keep tasks minimal and focused – one cohesive feature per task.
- Do not invent architecture. Follow the ADRs and vision docs.
